@@ -13,6 +13,27 @@ LayerInput = Annotated[Layer, {"label": "Image or labels"}]
 LabelsInput = Annotated[Labels, {"label": "Labels"}]
 global_magic_opts = {"auto_call": True}
 
+next_steps_at_the_beginning = [
+            "Remove noise",
+            "Remove background",
+            "Binarize",
+            "Label",
+            "Combine",
+            "Filter",
+        ]
+next_steps_after_labeling = [
+            "Process labels",
+            "Combine labels",
+            "Measure labels",
+            "Measure labeled image",
+            "Compare label images",
+            "Measurement",
+            "Mesh",
+        ]
+next_steps_after_measuring = [
+            "Label filters",
+            "Label neighbor filters"
+        ]
 
 @dataclass
 class Category:
@@ -21,6 +42,7 @@ class Category:
     inputs: Sequence[Type]
     default_op: str
     default_values : Sequence[float]
+    next_step_suggestions: Sequence[str] = field(default_factory=list)
     output: str = "image"  # or labels or dataframe
     # categories
     include: Sequence[str] = field(default_factory=tuple)
@@ -40,6 +62,7 @@ CATEGORIES = {
         inputs=(ImageInput,),
         default_op="gaussian_blur (clesperanto)",
         default_values=[1, 1, 0],
+        next_step_suggestions=next_steps_at_the_beginning,
         include=("filter", "denoise"),
         exclude=("combine",),
         tools_menu="Filtering / noise removal",
@@ -50,6 +73,12 @@ CATEGORIES = {
         inputs=(ImageInput,),
         default_op="top_hat_box (clesperanto)",
         default_values=[10, 10, 0],
+        next_step_suggestions=[
+            "Binarize",
+            "Label",
+            "Combine",
+            "Filter",
+        ],
         include=("filter", "background removal"),
         exclude=("combine",),
         tools_menu="Filtering / background removal",
@@ -60,6 +89,11 @@ CATEGORIES = {
         inputs=(ImageInput,),
         default_op="gamma_correction (clesperanto)",
         default_values=[1, 1, 0],
+        next_step_suggestions=[
+            "Binarize",
+            "Label",
+            "Combine",
+        ],
         include=("filter",),
         exclude=("combine", "denoise", "background removal", "binary processing"),
         tools_menu="Filtering",
@@ -72,6 +106,10 @@ CATEGORIES = {
         include=("combine",),
         exclude=("map", 'combine labels',),
         default_values=[1, 1],
+        next_step_suggestions=[
+            "Binarize",
+            "Label",
+        ],
         tools_menu="Image math",
     ),
     "Transform": Category(
@@ -81,6 +119,7 @@ CATEGORIES = {
         default_op="sub_stack (clesperanto)",
         output="image",  # can also be labels
         default_values=[0, 0, 0, 1, 1],
+        next_step_suggestions=next_steps_at_the_beginning,
         include=("transform",),
         exclude=("combine",),
         tools_menu="Transform",
@@ -91,6 +130,7 @@ CATEGORIES = {
         inputs=(LayerInput,),
         default_op="maximum_z_projection (clesperanto)",
         default_values=[1, 1, 1],
+        next_step_suggestions=next_steps_at_the_beginning,
         output="image",  # can also be labels
         include=("projection",),
         tools_menu="Projection",
@@ -102,6 +142,10 @@ CATEGORIES = {
         default_op="threshold_otsu (clesperanto)",
         output="labels",
         default_values=[1, 1, 0],
+        next_step_suggestions=[
+            "Label",
+            "Process labels",
+        ],
         include=("binarize",),
         exclude=("combine",),
         tools_menu="Segmentation / binarization",
@@ -113,6 +157,7 @@ CATEGORIES = {
         default_op="voronoi_otsu_labeling (clesperanto)",
         output="labels",
         default_values=[2, 2],
+        next_step_suggestions=next_steps_after_labeling,
         include=("label",),
         tools_menu="Segmentation / labeling",
     ),
@@ -123,6 +168,7 @@ CATEGORIES = {
         default_op="exclude_labels_on_edges (clesperanto)",
         output="labels",
         default_values=[2, 100],
+        next_step_suggestions=next_steps_after_labeling,
         include=("label processing",),
         exclude=("combine",),
         tools_menu="Segmentation post-processing",
@@ -134,6 +180,7 @@ CATEGORIES = {
         default_op="combine_labels (clesperanto)",
         output="labels",
         default_values=[2, 100],
+        next_step_suggestions=next_steps_after_labeling,
         include=("label processing","combine labels"),
         exclude=(),
         tools_menu="Segmentation post-processing",
@@ -144,6 +191,7 @@ CATEGORIES = {
         inputs=(LabelsInput,),
         default_op="pixel_count_map (clesperanto)",
         default_values=[1, 1],
+        next_step_suggestions=next_steps_after_measuring,
         include=("label measurement", "map"),
         exclude=("combine",),
         color_map="turbo",
@@ -155,6 +203,7 @@ CATEGORIES = {
         inputs=(ImageInput, LabelsInput),
         default_op="mean_intensity_map (clesperanto)",
         default_values=[1, 1],
+        next_step_suggestions=next_steps_after_measuring,
         include=("combine","label measurement", "map",),
         exclude=("label comparison",),
         color_map="turbo",
@@ -167,6 +216,7 @@ CATEGORIES = {
         output="image",
         default_op="label_overlap_count_map (clesperanto)",
         default_values=[],
+        next_step_suggestions=next_steps_after_measuring,
         include=("combine","label measurement", "map", "label comparison",),
         exclude=(),
         color_map="turbo",
@@ -178,6 +228,7 @@ CATEGORIES = {
         inputs=(ImageInput, LabelsInput),
         default_op="mean_of_n_nearest_neighbors_map (clesperanto)",
         default_values=[1, 100],
+        next_step_suggestions=next_steps_after_labeling,
         include=("neighbor",),
         color_map="turbo",
         tools_menu="Label neighbor filters",
@@ -189,6 +240,7 @@ CATEGORIES = {
         default_op="exclude_labels_with_map_values_out_of_range (clesperanto)",
         output="labels",
         default_values=[1, 100],
+        next_step_suggestions=next_steps_after_labeling,
         include=('label processing', 'combine'),
         exclude=("neighbor",),
         tools_menu="Segmentation post-processing",
@@ -199,6 +251,7 @@ CATEGORIES = {
         inputs=(LabelsInput,),
         default_op="draw_mesh_between_touching_labels (clesperanto)",
         default_values=[1],
+        next_step_suggestions=[],
         include=("label measurement", "mesh"),
         color_map="green",
         blending="additive",
@@ -211,6 +264,7 @@ CATEGORIES = {
         output="dataframe",
         default_op="Regionprops (nsr)",
         default_values=[],
+        next_step_suggestions=[],
         include=(),
         tools_menu="Measurement",
         auto_call=False
@@ -264,7 +318,7 @@ def get_name_of_function(func):
     and returns its human-readable name
     """
     for k, v in all_operations().items():
-        if v is func:
+        if v is func or v.__wrapped__ is func:
             if ">" in k:
                 return k.split(">")[1]
             else:
@@ -468,12 +522,15 @@ def find_function(op_name):
     return found_function
 
 
-def get_category_of_function(func):
+def get_category_of_function(func = None, func_name = None):
     """
     Searches categories for a given function and returns the first (!)
     category that contains the function
     """
-    func_name = get_name_of_function(func)
+    
+    if func_name is None:
+        func_name = get_name_of_function(func)
+
     for k, c in CATEGORIES.items():
         if not callable(c):
             ops = operations_in_menu(c)
